import java.io
import java.lang
import java.util
import typing



class BackingStoreException(java.lang.Exception):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class InvalidPreferencesFormatException(java.lang.Exception):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class NodeChangeEvent(java.util.EventObject):
    def __init__(self, preferences: 'Preferences', preferences2: 'Preferences'): ...
    def getChild(self) -> 'Preferences': ...
    def getParent(self) -> 'Preferences': ...

class NodeChangeListener(java.util.EventListener):
    def childAdded(self, nodeChangeEvent: NodeChangeEvent) -> None: ...
    def childRemoved(self, nodeChangeEvent: NodeChangeEvent) -> None: ...

class PreferenceChangeEvent(java.util.EventObject):
    def __init__(self, preferences: 'Preferences', string: str, string2: str): ...
    def getKey(self) -> str: ...
    def getNewValue(self) -> str: ...
    def getNode(self) -> 'Preferences': ...

class PreferenceChangeListener(java.util.EventListener):
    def preferenceChange(self, preferenceChangeEvent: PreferenceChangeEvent) -> None: ...

class Preferences:
    MAX_KEY_LENGTH: typing.ClassVar[int] = ...
    MAX_VALUE_LENGTH: typing.ClassVar[int] = ...
    MAX_NAME_LENGTH: typing.ClassVar[int] = ...
    def absolutePath(self) -> str: ...
    def addNodeChangeListener(self, nodeChangeListener: NodeChangeListener) -> None: ...
    def addPreferenceChangeListener(self, preferenceChangeListener: typing.Union[PreferenceChangeListener, typing.Callable]) -> None: ...
    def childrenNames(self) -> typing.List[str]: ...
    def clear(self) -> None: ...
    def exportNode(self, outputStream: java.io.OutputStream) -> None: ...
    def exportSubtree(self, outputStream: java.io.OutputStream) -> None: ...
    def flush(self) -> None: ...
    def get(self, string: str, string2: str) -> str: ...
    def getBoolean(self, string: str, boolean: bool) -> bool: ...
    def getByteArray(self, string: str, byteArray: typing.List[int]) -> typing.List[int]: ...
    def getDouble(self, string: str, double: float) -> float: ...
    def getFloat(self, string: str, float: float) -> float: ...
    def getInt(self, string: str, int: int) -> int: ...
    def getLong(self, string: str, long: int) -> int: ...
    @staticmethod
    def importPreferences(inputStream: java.io.InputStream) -> None: ...
    def isUserNode(self) -> bool: ...
    def keys(self) -> typing.List[str]: ...
    def name(self) -> str: ...
    def node(self, string: str) -> 'Preferences': ...
    def nodeExists(self, string: str) -> bool: ...
    def parent(self) -> 'Preferences': ...
    def put(self, string: str, string2: str) -> None: ...
    def putBoolean(self, string: str, boolean: bool) -> None: ...
    def putByteArray(self, string: str, byteArray: typing.List[int]) -> None: ...
    def putDouble(self, string: str, double: float) -> None: ...
    def putFloat(self, string: str, float: float) -> None: ...
    def putInt(self, string: str, int: int) -> None: ...
    def putLong(self, string: str, long: int) -> None: ...
    def remove(self, string: str) -> None: ...
    def removeNode(self) -> None: ...
    def removeNodeChangeListener(self, nodeChangeListener: NodeChangeListener) -> None: ...
    def removePreferenceChangeListener(self, preferenceChangeListener: typing.Union[PreferenceChangeListener, typing.Callable]) -> None: ...
    def sync(self) -> None: ...
    @staticmethod
    def systemNodeForPackage(class_: typing.Type[typing.Any]) -> 'Preferences': ...
    @staticmethod
    def systemRoot() -> 'Preferences': ...
    def toString(self) -> str: ...
    @staticmethod
    def userNodeForPackage(class_: typing.Type[typing.Any]) -> 'Preferences': ...
    @staticmethod
    def userRoot() -> 'Preferences': ...

class PreferencesFactory:
    def systemRoot(self) -> Preferences: ...
    def userRoot(self) -> Preferences: ...

class AbstractPreferences(Preferences):
    def absolutePath(self) -> str: ...
    def addNodeChangeListener(self, nodeChangeListener: NodeChangeListener) -> None: ...
    def addPreferenceChangeListener(self, preferenceChangeListener: typing.Union[PreferenceChangeListener, typing.Callable]) -> None: ...
    def childrenNames(self) -> typing.List[str]: ...
    def clear(self) -> None: ...
    def exportNode(self, outputStream: java.io.OutputStream) -> None: ...
    def exportSubtree(self, outputStream: java.io.OutputStream) -> None: ...
    def flush(self) -> None: ...
    def get(self, string: str, string2: str) -> str: ...
    def getBoolean(self, string: str, boolean: bool) -> bool: ...
    def getByteArray(self, string: str, byteArray: typing.List[int]) -> typing.List[int]: ...
    def getDouble(self, string: str, double: float) -> float: ...
    def getFloat(self, string: str, float: float) -> float: ...
    def getInt(self, string: str, int: int) -> int: ...
    def getLong(self, string: str, long: int) -> int: ...
    def isUserNode(self) -> bool: ...
    def keys(self) -> typing.List[str]: ...
    def name(self) -> str: ...
    def node(self, string: str) -> Preferences: ...
    def nodeExists(self, string: str) -> bool: ...
    def parent(self) -> Preferences: ...
    def put(self, string: str, string2: str) -> None: ...
    def putBoolean(self, string: str, boolean: bool) -> None: ...
    def putByteArray(self, string: str, byteArray: typing.List[int]) -> None: ...
    def putDouble(self, string: str, double: float) -> None: ...
    def putFloat(self, string: str, float: float) -> None: ...
    def putInt(self, string: str, int: int) -> None: ...
    def putLong(self, string: str, long: int) -> None: ...
    def remove(self, string: str) -> None: ...
    def removeNode(self) -> None: ...
    def removeNodeChangeListener(self, nodeChangeListener: NodeChangeListener) -> None: ...
    def removePreferenceChangeListener(self, preferenceChangeListener: typing.Union[PreferenceChangeListener, typing.Callable]) -> None: ...
    def sync(self) -> None: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.util.prefs")``.

    AbstractPreferences: typing.Type[AbstractPreferences]
    BackingStoreException: typing.Type[BackingStoreException]
    InvalidPreferencesFormatException: typing.Type[InvalidPreferencesFormatException]
    NodeChangeEvent: typing.Type[NodeChangeEvent]
    NodeChangeListener: typing.Type[NodeChangeListener]
    PreferenceChangeEvent: typing.Type[PreferenceChangeEvent]
    PreferenceChangeListener: typing.Type[PreferenceChangeListener]
    Preferences: typing.Type[Preferences]
    PreferencesFactory: typing.Type[PreferencesFactory]



import org.ergoplatform.explorer.client
import typing


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.explorer")``.

    client: org.ergoplatform.explorer.client.__module_protocol__



import java.lang
import java.net
import scala
import scala.collection
import scala.collection.immutable
import scala.reflect
import scala.reflect.api
import scala.reflect.internal.util
import scala.reflect.macros.blackbox
import scala.reflect.macros.internal
import scala.reflect.macros.whitebox
import scala.runtime
import typing



class Aliases:
    @staticmethod
    def $init$($this: 'Aliases') -> None: ...
    _Expr_0__T = typing.TypeVar('_Expr_0__T')  # <T>
    @typing.overload
    def Expr(self, tree: scala.reflect.api.Trees.TreeApi, evidence$1: scala.reflect.api.TypeTags.WeakTypeTag[_Expr_0__T]) -> scala.reflect.api.Exprs.Expr[_Expr_0__T]: ...
    @typing.overload
    def Expr(self) -> scala.reflect.api.Exprs.Expr.: ...
    _TypeTag_0__T = typing.TypeVar('_TypeTag_0__T')  # <T>
    @typing.overload
    def TypeTag(self, tpe: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.TypeTags.TypeTag[_TypeTag_0__T]: ...
    @typing.overload
    def TypeTag(self) -> scala.reflect.api.TypeTags.TypeTag.: ...
    _WeakTypeTag_0__T = typing.TypeVar('_WeakTypeTag_0__T')  # <T>
    @typing.overload
    def WeakTypeTag(self, tpe: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.TypeTags.WeakTypeTag[_WeakTypeTag_0__T]: ...
    @typing.overload
    def WeakTypeTag(self) -> scala.reflect.api.TypeTags.WeakTypeTag.: ...
    def scala$reflect$macros$Aliases$_setter_$Expr_$eq(self, x$1: scala.reflect.api.Exprs.Expr.) -> None: ...
    def scala$reflect$macros$Aliases$_setter_$TypeTag_$eq(self, x$1: scala.reflect.api.TypeTags.TypeTag.) -> None: ...
    def scala$reflect$macros$Aliases$_setter_$WeakTypeTag_$eq(self, x$1: scala.reflect.api.TypeTags.WeakTypeTag.) -> None: ...
    _symbolOf__T = typing.TypeVar('_symbolOf__T')  # <T>
    def symbolOf(self, evidence$2: scala.reflect.api.TypeTags.WeakTypeTag[_symbolOf__T]) -> scala.reflect.api.Symbols.TypeSymbolApi: ...
    _typeOf__T = typing.TypeVar('_typeOf__T')  # <T>
    def typeOf(self, ttag: scala.reflect.api.TypeTags.TypeTag[_typeOf__T]) -> scala.reflect.api.Types.TypeApi: ...
    _typeTag__T = typing.TypeVar('_typeTag__T')  # <T>
    def typeTag(self, ttag: scala.reflect.api.TypeTags.TypeTag[_typeTag__T]) -> scala.reflect.api.TypeTags.TypeTag[_typeTag__T]: ...
    _weakTypeOf__T = typing.TypeVar('_weakTypeOf__T')  # <T>
    def weakTypeOf(self, attag: scala.reflect.api.TypeTags.WeakTypeTag[_weakTypeOf__T]) -> scala.reflect.api.Types.TypeApi: ...
    _weakTypeTag__T = typing.TypeVar('_weakTypeTag__T')  # <T>
    def weakTypeTag(self, attag: scala.reflect.api.TypeTags.WeakTypeTag[_weakTypeTag__T]) -> scala.reflect.api.TypeTags.WeakTypeTag[_weakTypeTag__T]: ...

class Attachments:
    def __init__(self): ...
    def all(self) -> scala.collection.immutable.Set[typing.Any]: ...
    _contains__T = typing.TypeVar('_contains__T')  # <T>
    def contains(self, evidence$3: scala.reflect.ClassTag[_contains__T]) -> bool: ...
    _get__T = typing.TypeVar('_get__T')  # <T>
    def get(self, evidence$2: scala.reflect.ClassTag[_get__T]) -> scala.Option[_get__T]: ...
    def isEmpty(self) -> bool: ...
    def pos(self) -> typing.Any: ...
    _remove__T = typing.TypeVar('_remove__T')  # <T>
    def remove(self, evidence$5: scala.reflect.ClassTag[_remove__T]) -> 'Attachments': ...
    _update__T = typing.TypeVar('_update__T')  # <T>
    def update(self, attachment: _update__T, evidence$4: scala.reflect.ClassTag[_update__T]) -> 'Attachments': ...
    def withPos(self, newPos: typing.Any) -> 'Attachments': ...

class Enclosures:
    @staticmethod
    def $init$($this: 'Enclosures') -> None: ...
    def enclosingClass(self) -> scala.reflect.api.Trees.TreeApi: ...
    def enclosingDef(self) -> scala.reflect.api.Trees.DefDefApi: ...
    def enclosingImpl(self) -> scala.reflect.api.Trees.ImplDefApi: ...
    def enclosingMacros(self) -> scala.collection.immutable.List[scala.reflect.macros.blackbox.Context]: ...
    def enclosingMethod(self) -> scala.reflect.api.Trees.TreeApi: ...
    def enclosingPackage(self) -> scala.reflect.api.Trees.PackageDefApi: ...
    def enclosingPosition(self) -> scala.reflect.api.Position: ...
    def enclosingRun(self) -> 'Universe.RunContextApi': ...
    def enclosingTemplate(self) -> scala.reflect.api.Trees.TemplateApi: ...
    def enclosingUnit(self) -> 'Universe.CompilationUnitContextApi': ...
    def macroApplication(self) -> scala.reflect.api.Trees.TreeApi: ...
    class EnclosureException(java.lang.Exception, scala.Product, scala.Serializable):
        $outer: scala.reflect.macros.blackbox.Context = ...
        def __init__(self, $outer: scala.reflect.macros.blackbox.Context, expected: typing.Type[typing.Any], enclosingTrees: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]): ...
        def canEqual(self, x$1: typing.Any) -> bool: ...
        def copy(self, expected: typing.Type[typing.Any], enclosingTrees: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> 'Enclosures.EnclosureException': ...
        def copy$default$1(self) -> typing.Type[typing.Any]: ...
        def copy$default$2(self) -> scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]: ...
        def enclosingTrees(self) -> scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]: ...
        def equals(self, x$1: typing.Any) -> bool: ...
        def expected(self) -> typing.Type[typing.Any]: ...
        def hashCode(self) -> int: ...
        def productArity(self) -> int: ...
        def productElement(self, x$1: int) -> typing.Any: ...
        def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
        def productPrefix(self) -> str: ...
    class EnclosureException$(scala.runtime.AbstractFunction2[typing.Type[typing.Any], scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi], 'Enclosures.EnclosureException'], scala.Serializable):
        def __init__(self, $outer: scala.reflect.macros.blackbox.Context): ...
        def apply(self, expected: typing.Type[typing.Any], enclosingTrees: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> 'Enclosures.EnclosureException': ...
        def toString(self) -> str: ...
        def unapply(self, x$0: 'Enclosures.EnclosureException') -> scala.Option[scala.Tuple2[typing.Type[typing.Any], scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]]]: ...

class Evals:
    _eval__T = typing.TypeVar('_eval__T')  # <T>
    def eval(self, expr: scala.reflect.api.Exprs.Expr[_eval__T]) -> _eval__T: ...

class ExprUtils:
    @typing.overload
    def literal(self, x: bool) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    @typing.overload
    def literal(self, x: int) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    @typing.overload
    def literal(self, x: str) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    @typing.overload
    def literal(self, x: float) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    @typing.overload
    def literal(self, x: float) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    @typing.overload
    def literal(self, x: int) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    @typing.overload
    def literal(self, x: str) -> scala.reflect.api.Exprs.Expr[str]: ...
    @typing.overload
    def literal(self, x: int) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    @typing.overload
    def literal(self, x: int) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    def literalFalse(self) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    def literalNull(self) -> scala.reflect.api.Exprs.Expr[scala.runtime.Null.]: ...
    def literalTrue(self) -> scala.reflect.api.Exprs.Expr[typing.Any]: ...
    def literalUnit(self) -> scala.reflect.api.Exprs.Expr[scala.runtime.BoxedUnit]: ...

class FrontEnds:
    def abort(self, pos: scala.reflect.api.Position, msg: str) -> scala.runtime.Nothing.: ...
    def echo(self, pos: scala.reflect.api.Position, msg: str) -> None: ...
    def error(self, pos: scala.reflect.api.Position, msg: str) -> None: ...
    def hasErrors(self) -> bool: ...
    def hasWarnings(self) -> bool: ...
    def info(self, pos: scala.reflect.api.Position, msg: str, force: bool) -> None: ...
    def warning(self, pos: scala.reflect.api.Position, msg: str) -> None: ...

class Infrastructure:
    def classPath(self) -> scala.collection.immutable.List[java.net.URL]: ...
    def compilerSettings(self) -> scala.collection.immutable.List[str]: ...
    def settings(self) -> scala.collection.immutable.List[str]: ...

class Names:
    _fresh_2__NameType = typing.TypeVar('_fresh_2__NameType', bound=scala.reflect.api.Names.NameApi)  # <NameType>
    @typing.overload
    def fresh(self) -> str: ...
    @typing.overload
    def fresh(self, name: str) -> str: ...
    @typing.overload
    def fresh(self, name: _fresh_2__NameType) -> _fresh_2__NameType: ...
    _freshName_2__NameType = typing.TypeVar('_freshName_2__NameType', bound=scala.reflect.api.Names.NameApi)  # <NameType>
    @typing.overload
    def freshName(self) -> str: ...
    @typing.overload
    def freshName(self, name: str) -> str: ...
    @typing.overload
    def freshName(self, name: _freshName_2__NameType) -> _freshName_2__NameType: ...

class ParseException(java.lang.Exception, scala.Product, scala.Serializable):
    def __init__(self, pos: scala.reflect.api.Position, msg: str): ...
    @staticmethod
    def apply(pos: scala.reflect.api.Position, msg: str) -> 'ParseException': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, pos: scala.reflect.api.Position, msg: str) -> 'ParseException': ...
    def copy$default$1(self) -> scala.reflect.api.Position: ...
    def copy$default$2(self) -> str: ...
    @staticmethod
    def curried() -> scala.Function1[scala.reflect.api.Position, scala.Function1[str, 'ParseException']]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def msg(self) -> str: ...
    def pos(self) -> scala.reflect.api.Position: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> str: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple2[scala.reflect.api.Position, str], 'ParseException']: ...
    @staticmethod
    def unapply(x$0: 'ParseException') -> scala.Option[scala.Tuple2[scala.reflect.api.Position, str]]: ...

class Parsers:
    def parse(self, code: str) -> scala.reflect.api.Trees.TreeApi: ...

class ReificationException(java.lang.Exception, scala.Product, scala.Serializable):
    def __init__(self, pos: scala.reflect.api.Position, msg: str): ...
    @staticmethod
    def apply(pos: scala.reflect.api.Position, msg: str) -> 'ReificationException': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, pos: scala.reflect.api.Position, msg: str) -> 'ReificationException': ...
    def copy$default$1(self) -> scala.reflect.api.Position: ...
    def copy$default$2(self) -> str: ...
    @staticmethod
    def curried() -> scala.Function1[scala.reflect.api.Position, scala.Function1[str, 'ReificationException']]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def msg(self) -> str: ...
    def pos(self) -> scala.reflect.api.Position: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> str: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple2[scala.reflect.api.Position, str], 'ReificationException']: ...
    @staticmethod
    def unapply(x$0: 'ReificationException') -> scala.Option[scala.Tuple2[scala.reflect.api.Position, str]]: ...

class Reifiers:
    def reifyEnclosingRuntimeClass(self) -> scala.reflect.api.Trees.TreeApi: ...
    def reifyRuntimeClass(self, tpe: scala.reflect.api.Types.TypeApi, concrete: bool) -> scala.reflect.api.Trees.TreeApi: ...
    def reifyRuntimeClass$default$2(self) -> bool: ...
    def reifyTree(self, universe: scala.reflect.api.Trees.TreeApi, mirror: scala.reflect.api.Trees.TreeApi, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...
    def reifyType(self, universe: scala.reflect.api.Trees.TreeApi, mirror: scala.reflect.api.Trees.TreeApi, tpe: scala.reflect.api.Types.TypeApi, concrete: bool) -> scala.reflect.api.Trees.TreeApi: ...
    def reifyType$default$4(self) -> bool: ...
    def unreifyTree(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...

class TypecheckException(java.lang.Exception, scala.Product, scala.Serializable):
    def __init__(self, pos: scala.reflect.api.Position, msg: str): ...
    @staticmethod
    def apply(pos: scala.reflect.api.Position, msg: str) -> 'TypecheckException': ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def copy(self, pos: scala.reflect.api.Position, msg: str) -> 'TypecheckException': ...
    def copy$default$1(self) -> scala.reflect.api.Position: ...
    def copy$default$2(self) -> str: ...
    @staticmethod
    def curried() -> scala.Function1[scala.reflect.api.Position, scala.Function1[str, 'TypecheckException']]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def msg(self) -> str: ...
    def pos(self) -> scala.reflect.api.Position: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> str: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple2[scala.reflect.api.Position, str], 'TypecheckException']: ...
    @staticmethod
    def unapply(x$0: 'TypecheckException') -> scala.Option[scala.Tuple2[scala.reflect.api.Position, str]]: ...

class Typers:
    @staticmethod
    def $init$($this: 'Typers') -> None: ...
    def PATTERNmode(self) -> typing.Any: ...
    def TERMmode(self) -> typing.Any: ...
    def TYPEmode(self) -> typing.Any: ...
    def TypecheckException(self) -> 'TypecheckException.': ...
    def inferImplicitValue(self, pt: scala.reflect.api.Types.TypeApi, silent: bool, withMacrosDisabled: bool, pos: scala.reflect.api.Position) -> scala.reflect.api.Trees.TreeApi: ...
    def inferImplicitValue$default$2(self) -> bool: ...
    def inferImplicitValue$default$3(self) -> bool: ...
    def inferImplicitValue$default$4(self) -> scala.reflect.api.Position: ...
    def inferImplicitView(self, tree: scala.reflect.api.Trees.TreeApi, from_: scala.reflect.api.Types.TypeApi, to: scala.reflect.api.Types.TypeApi, silent: bool, withMacrosDisabled: bool, pos: scala.reflect.api.Position) -> scala.reflect.api.Trees.TreeApi: ...
    def inferImplicitView$default$4(self) -> bool: ...
    def inferImplicitView$default$5(self) -> bool: ...
    def inferImplicitView$default$6(self) -> scala.reflect.api.Position: ...
    def openMacros(self) -> scala.collection.immutable.List[scala.reflect.macros.blackbox.Context]: ...
    def resetLocalAttrs(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...
    def scala$reflect$macros$Typers$_setter_$TypecheckException_$eq(self, x$1: 'TypecheckException.') -> None: ...
    def typeCheck(self, tree: scala.reflect.api.Trees.TreeApi, pt: scala.reflect.api.Types.TypeApi, silent: bool, withImplicitViewsDisabled: bool, withMacrosDisabled: bool) -> scala.reflect.api.Trees.TreeApi: ...
    def typeCheck$default$2(self) -> scala.reflect.api.Types.TypeApi: ...
    def typeCheck$default$3(self) -> bool: ...
    def typeCheck$default$4(self) -> bool: ...
    def typeCheck$default$5(self) -> bool: ...
    def typecheck(self, tree: scala.reflect.api.Trees.TreeApi, mode: typing.Any, pt: scala.reflect.api.Types.TypeApi, silent: bool, withImplicitViewsDisabled: bool, withMacrosDisabled: bool) -> scala.reflect.api.Trees.TreeApi: ...
    def typecheck$default$2(self) -> typing.Any: ...
    def typecheck$default$3(self) -> scala.reflect.api.Types.TypeApi: ...
    def typecheck$default$4(self) -> bool: ...
    def typecheck$default$5(self) -> bool: ...
    def typecheck$default$6(self) -> bool: ...
    def untypecheck(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...

class UnexpectedReificationException(java.lang.Exception, scala.Product, scala.Serializable):
    def __init__(self, pos: scala.reflect.api.Position, msg: str, cause: java.lang.Throwable): ...
    @staticmethod
    def $lessinit$greater$default$3() -> java.lang.Throwable: ...
    @staticmethod
    def apply(pos: scala.reflect.api.Position, msg: str, cause: java.lang.Throwable) -> 'UnexpectedReificationException': ...
    @staticmethod
    def apply$default$3() -> java.lang.Throwable: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    def cause(self) -> java.lang.Throwable: ...
    def copy(self, pos: scala.reflect.api.Position, msg: str, cause: java.lang.Throwable) -> 'UnexpectedReificationException': ...
    def copy$default$1(self) -> scala.reflect.api.Position: ...
    def copy$default$2(self) -> str: ...
    def copy$default$3(self) -> java.lang.Throwable: ...
    @staticmethod
    def curried() -> scala.Function1[scala.reflect.api.Position, scala.Function1[str, scala.Function1[java.lang.Throwable, 'UnexpectedReificationException']]]: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def msg(self) -> str: ...
    def pos(self) -> scala.reflect.api.Position: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> str: ...
    @staticmethod
    def tupled() -> scala.Function1[scala.Tuple3[scala.reflect.api.Position, str, java.lang.Throwable], 'UnexpectedReificationException']: ...
    @staticmethod
    def unapply(x$0: 'UnexpectedReificationException') -> scala.Option[scala.Tuple3[scala.reflect.api.Position, str, java.lang.Throwable]]: ...

_Universe__MacroInternalApi__MacroDecoratorApi__MacroScopeDecoratorApi__T = typing.TypeVar('_Universe__MacroInternalApi__MacroDecoratorApi__MacroScopeDecoratorApi__T', bound=scala.reflect.api.Scopes.ScopeApi)  # <T>
_Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T = typing.TypeVar('_Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T', bound=scala.reflect.api.Symbols.SymbolApi)  # <T>
_Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T = typing.TypeVar('_Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T', bound=scala.reflect.api.Trees.TreeApi)  # <T>
_Universe__MacroInternalApi__MacroDecoratorApi__MacroTypeTreeDecoratorApi__T = typing.TypeVar('_Universe__MacroInternalApi__MacroDecoratorApi__MacroTypeTreeDecoratorApi__T', bound=scala.reflect.api.Trees.TypeTreeApi)  # <T>
class Universe(scala.reflect.api.Universe):
    def __init__(self): ...
    def treeBuild(self) -> 'Universe.TreeGen': ...
    class CompilationUnitContextApi:
        def body(self) -> scala.reflect.api.Trees.TreeApi: ...
        def source(self) -> scala.reflect.internal.util.SourceFile: ...
    class MacroCompatApi(scala.reflect.api.Internals.CompatApi):
        @staticmethod
        def $init$($this: 'Universe.MacroCompatApi') -> None: ...
        def captureVariable(self, vble: scala.reflect.api.Symbols.SymbolApi) -> None: ...
        def capturedVariableType(self, vble: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Types.TypeApi: ...
        def referenceCapturedVariable(self, vble: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
        class CompatibleTypeTree:
            $outer: 'Universe.MacroCompatApi' = ...
            def __init__(self, $outer: 'Universe.MacroCompatApi', tt: scala.reflect.api.Trees.TypeTreeApi): ...
            def setOriginal(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TypeTreeApi: ...
        class MacroCompatibleSymbol:
            $outer: 'Universe.MacroCompatApi' = ...
            def __init__(self, $outer: 'Universe.MacroCompatApi', symbol: scala.reflect.api.Symbols.SymbolApi): ...
            def attachments(self) -> Attachments: ...
            _removeAttachment__T = typing.TypeVar('_removeAttachment__T')  # <T>
            def removeAttachment(self, evidence$10: scala.reflect.ClassTag[_removeAttachment__T]) -> scala.reflect.api.Symbols.SymbolApi: ...
            def setAnnotations(self, annots: scala.collection.Seq[scala.reflect.api.Annotations.AnnotationApi]) -> scala.reflect.api.Symbols.SymbolApi: ...
            def setName(self, name: scala.reflect.api.Names.NameApi) -> scala.reflect.api.Symbols.SymbolApi: ...
            def setPrivateWithin(self, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Symbols.SymbolApi: ...
            def setTypeSignature(self, tpe: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Symbols.SymbolApi: ...
            _updateAttachment__T = typing.TypeVar('_updateAttachment__T')  # <T>
            def updateAttachment(self, attachment: _updateAttachment__T, evidence$9: scala.reflect.ClassTag[_updateAttachment__T]) -> scala.reflect.api.Symbols.SymbolApi: ...
        class MacroCompatibleTree:
            $outer: 'Universe.MacroCompatApi' = ...
            def __init__(self, $outer: 'Universe.MacroCompatApi', tree: scala.reflect.api.Trees.TreeApi): ...
            def attachments(self) -> Attachments: ...
            def defineType(self, tp: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Trees.TreeApi: ...
            def pos_$eq(self, pos: scala.reflect.api.Position) -> None: ...
            _removeAttachment__T = typing.TypeVar('_removeAttachment__T')  # <T>
            def removeAttachment(self, evidence$12: scala.reflect.ClassTag[_removeAttachment__T]) -> scala.reflect.api.Trees.TreeApi: ...
            def setPos(self, newpos: scala.reflect.api.Position) -> scala.reflect.api.Trees.TreeApi: ...
            def setSymbol(self, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
            def setType(self, tp: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Trees.TreeApi: ...
            def symbol_$eq(self, sym: scala.reflect.api.Symbols.SymbolApi) -> None: ...
            def tpe_$eq(self, t: scala.reflect.api.Types.TypeApi) -> None: ...
            _updateAttachment__T = typing.TypeVar('_updateAttachment__T')  # <T>
            def updateAttachment(self, attachment: _updateAttachment__T, evidence$11: scala.reflect.ClassTag[_updateAttachment__T]) -> scala.reflect.api.Trees.TreeApi: ...
    class MacroInternalApi(scala.reflect.api.Internals.InternalApi):
        @staticmethod
        def $init$($this: 'Universe.MacroInternalApi') -> None: ...
        @typing.overload
        def attachments(self, symbol: scala.reflect.api.Symbols.SymbolApi) -> Attachments: ...
        @typing.overload
        def attachments(self, tree: scala.reflect.api.Trees.TreeApi) -> Attachments: ...
        def captureVariable(self, vble: scala.reflect.api.Symbols.SymbolApi) -> None: ...
        def capturedVariableType(self, vble: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Types.TypeApi: ...
        def changeOwner(self, tree: scala.reflect.api.Trees.TreeApi, prev: scala.reflect.api.Symbols.SymbolApi, next: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
        def defineType(self, tree: scala.reflect.api.Trees.TreeApi, tp: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Trees.TreeApi: ...
        def enter(self, scope: scala.reflect.api.Scopes.ScopeApi, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Scopes.ScopeApi: ...
        def gen(self) -> 'Universe.TreeGen': ...
        def referenceCapturedVariable(self, vble: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
        _removeAttachment_0__T = typing.TypeVar('_removeAttachment_0__T')  # <T>
        _removeAttachment_1__T = typing.TypeVar('_removeAttachment_1__T')  # <T>
        @typing.overload
        def removeAttachment(self, symbol: scala.reflect.api.Symbols.SymbolApi, evidence$2: scala.reflect.ClassTag[_removeAttachment_0__T]) -> scala.reflect.api.Symbols.SymbolApi: ...
        @typing.overload
        def removeAttachment(self, tree: scala.reflect.api.Trees.TreeApi, evidence$4: scala.reflect.ClassTag[_removeAttachment_1__T]) -> scala.reflect.api.Trees.TreeApi: ...
        def resetFlag(self, symbol: scala.reflect.api.Symbols.SymbolApi, flags: typing.Any) -> scala.reflect.api.Symbols.SymbolApi: ...
        def setAnnotations(self, symbol: scala.reflect.api.Symbols.SymbolApi, annots: scala.collection.Seq[scala.reflect.api.Annotations.AnnotationApi]) -> scala.reflect.api.Symbols.SymbolApi: ...
        def setFlag(self, symbol: scala.reflect.api.Symbols.SymbolApi, flags: typing.Any) -> scala.reflect.api.Symbols.SymbolApi: ...
        def setInfo(self, symbol: scala.reflect.api.Symbols.SymbolApi, tpe: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Symbols.SymbolApi: ...
        def setName(self, symbol: scala.reflect.api.Symbols.SymbolApi, name: scala.reflect.api.Names.NameApi) -> scala.reflect.api.Symbols.SymbolApi: ...
        def setOriginal(self, tt: scala.reflect.api.Trees.TypeTreeApi, original: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TypeTreeApi: ...
        def setOwner(self, symbol: scala.reflect.api.Symbols.SymbolApi, newowner: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Symbols.SymbolApi: ...
        def setPos(self, tree: scala.reflect.api.Trees.TreeApi, newpos: scala.reflect.api.Position) -> scala.reflect.api.Trees.TreeApi: ...
        def setPrivateWithin(self, symbol: scala.reflect.api.Symbols.SymbolApi, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Symbols.SymbolApi: ...
        def setSymbol(self, tree: scala.reflect.api.Trees.TreeApi, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
        def setType(self, tree: scala.reflect.api.Trees.TreeApi, tp: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Trees.TreeApi: ...
        def subpatterns(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.Option[scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]]: ...
        def unlink(self, scope: scala.reflect.api.Scopes.ScopeApi, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Scopes.ScopeApi: ...
        _updateAttachment_0__T = typing.TypeVar('_updateAttachment_0__T')  # <T>
        _updateAttachment_1__T = typing.TypeVar('_updateAttachment_1__T')  # <T>
        @typing.overload
        def updateAttachment(self, symbol: scala.reflect.api.Symbols.SymbolApi, attachment: _updateAttachment_0__T, evidence$1: scala.reflect.ClassTag[_updateAttachment_0__T]) -> scala.reflect.api.Symbols.SymbolApi: ...
        @typing.overload
        def updateAttachment(self, tree: scala.reflect.api.Trees.TreeApi, attachment: _updateAttachment_1__T, evidence$3: scala.reflect.ClassTag[_updateAttachment_1__T]) -> scala.reflect.api.Trees.TreeApi: ...
        class MacroDecoratorApi(scala.reflect.api.Internals.InternalApi.DecoratorApi):
            @staticmethod
            def $init$($this: 'Universe.MacroInternalApi.MacroDecoratorApi') -> None: ...
            _scopeDecorator__T = typing.TypeVar('_scopeDecorator__T', bound=scala.reflect.api.Scopes.ScopeApi)  # <T>
            def scopeDecorator(self, tree: _scopeDecorator__T) -> 'Universe.MacroInternalApi.MacroDecoratorApi.MacroScopeDecoratorApi': ...
            _typeTreeDecorator__T = typing.TypeVar('_typeTreeDecorator__T', bound=scala.reflect.api.Trees.TypeTreeApi)  # <T>
            def typeTreeDecorator(self, tt: _typeTreeDecorator__T) -> 'Universe.MacroInternalApi.MacroDecoratorApi.MacroTypeTreeDecoratorApi': ...
            class MacroScopeDecoratorApi(typing.Generic[_Universe__MacroInternalApi__MacroDecoratorApi__MacroScopeDecoratorApi__T]):
                $outer: 'Universe.MacroInternalApi.MacroDecoratorApi' = ...
                def __init__(self, $outer: 'Universe.MacroInternalApi.MacroDecoratorApi', scope: _Universe__MacroInternalApi__MacroDecoratorApi__MacroScopeDecoratorApi__T): ...
                def enter(self, sym: scala.reflect.api.Symbols.SymbolApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroScopeDecoratorApi__T: ...
                def scope(self) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroScopeDecoratorApi__T: ...
                def unlink(self, sym: scala.reflect.api.Symbols.SymbolApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroScopeDecoratorApi__T: ...
            class MacroSymbolDecoratorApi(scala.reflect.api.Internals.InternalApi.DecoratorApi.SymbolDecoratorApi[_Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T], typing.Generic[_Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T]):
                def __init__(self, $outer: 'Universe.MacroInternalApi.MacroDecoratorApi', symbol: _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T): ...
                def attachments(self) -> Attachments: ...
                _removeAttachment__A = typing.TypeVar('_removeAttachment__A')  # <A>
                def removeAttachment(self, evidence$8: scala.reflect.ClassTag[_removeAttachment__A]) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def resetFlag(self, flags: typing.Any) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def setAnnotations(self, annots: scala.collection.Seq[scala.reflect.api.Annotations.AnnotationApi]) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def setFlag(self, flags: typing.Any) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def setInfo(self, tpe: scala.reflect.api.Types.TypeApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def setName(self, name: scala.reflect.api.Names.NameApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def setOwner(self, newowner: scala.reflect.api.Symbols.SymbolApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def setPrivateWithin(self, sym: scala.reflect.api.Symbols.SymbolApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                def symbol(self) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
                _updateAttachment__A = typing.TypeVar('_updateAttachment__A')  # <A>
                def updateAttachment(self, attachment: _updateAttachment__A, evidence$7: scala.reflect.ClassTag[_updateAttachment__A]) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroSymbolDecoratorApi__T: ...
            class MacroTreeDecoratorApi(scala.reflect.api.Internals.InternalApi.DecoratorApi.TreeDecoratorApi[_Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T], typing.Generic[_Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T]):
                def __init__(self, $outer: 'Universe.MacroInternalApi.MacroDecoratorApi', tree: _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T): ...
                def attachments(self) -> Attachments: ...
                def changeOwner(self, prev: scala.reflect.api.Symbols.SymbolApi, next: scala.reflect.api.Symbols.SymbolApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
                def defineType(self, tp: scala.reflect.api.Types.TypeApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
                _removeAttachment__A = typing.TypeVar('_removeAttachment__A')  # <A>
                def removeAttachment(self, evidence$6: scala.reflect.ClassTag[_removeAttachment__A]) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
                def setPos(self, newpos: scala.reflect.api.Position) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
                def setSymbol(self, sym: scala.reflect.api.Symbols.SymbolApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
                def setType(self, tp: scala.reflect.api.Types.TypeApi) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
                def tree(self) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
                _updateAttachment__A = typing.TypeVar('_updateAttachment__A')  # <A>
                def updateAttachment(self, attachment: _updateAttachment__A, evidence$5: scala.reflect.ClassTag[_updateAttachment__A]) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTreeDecoratorApi__T: ...
            class MacroTypeTreeDecoratorApi(typing.Generic[_Universe__MacroInternalApi__MacroDecoratorApi__MacroTypeTreeDecoratorApi__T]):
                $outer: 'Universe.MacroInternalApi.MacroDecoratorApi' = ...
                def __init__(self, $outer: 'Universe.MacroInternalApi.MacroDecoratorApi', tt: _Universe__MacroInternalApi__MacroDecoratorApi__MacroTypeTreeDecoratorApi__T): ...
                def setOriginal(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TypeTreeApi: ...
                def tt(self) -> _Universe__MacroInternalApi__MacroDecoratorApi__MacroTypeTreeDecoratorApi__T: ...
    class RunContextApi:
        def currentUnit(self) -> 'Universe.CompilationUnitContextApi': ...
        def units(self) -> scala.collection.Iterator['Universe.CompilationUnitContextApi']: ...
    class TreeGen:
        def mkAttributedIdent(self, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.RefTreeApi: ...
        @typing.overload
        def mkAttributedQualifier(self, tpe: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkAttributedQualifier(self, tpe: scala.reflect.api.Types.TypeApi, termSym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkAttributedRef(self, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.RefTreeApi: ...
        @typing.overload
        def mkAttributedRef(self, pre: scala.reflect.api.Types.TypeApi, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.RefTreeApi: ...
        def mkAttributedSelect(self, qual: scala.reflect.api.Trees.TreeApi, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.RefTreeApi: ...
        @typing.overload
        def mkAttributedStableRef(self, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkAttributedStableRef(self, pre: scala.reflect.api.Types.TypeApi, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.TreeApi: ...
        def mkAttributedThis(self, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.ThisApi: ...
        def mkCast(self, tree: scala.reflect.api.Trees.TreeApi, pt: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkMethodCall(self, method: scala.reflect.api.Symbols.SymbolApi, args: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkMethodCall(self, method: scala.reflect.api.Symbols.SymbolApi, targs: scala.collection.immutable.List[scala.reflect.api.Types.TypeApi], args: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkMethodCall(self, receiver: scala.reflect.api.Symbols.SymbolApi, methodName: scala.reflect.api.Names.NameApi, args: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkMethodCall(self, receiver: scala.reflect.api.Symbols.SymbolApi, methodName: scala.reflect.api.Names.NameApi, targs: scala.collection.immutable.List[scala.reflect.api.Types.TypeApi], args: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkMethodCall(self, target: scala.reflect.api.Trees.TreeApi, args: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkMethodCall(self, target: scala.reflect.api.Trees.TreeApi, targs: scala.collection.immutable.List[scala.reflect.api.Types.TypeApi], args: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkMethodCall(self, receiver: scala.reflect.api.Trees.TreeApi, method: scala.reflect.api.Symbols.SymbolApi, targs: scala.collection.immutable.List[scala.reflect.api.Types.TypeApi], args: scala.collection.immutable.List[scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        def mkNullaryCall(self, method: scala.reflect.api.Symbols.SymbolApi, targs: scala.collection.immutable.List[scala.reflect.api.Types.TypeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        def mkRuntimeUniverseRef(self) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def mkUnattributedRef(self, fullName: scala.reflect.api.Names.NameApi) -> scala.reflect.api.Trees.RefTreeApi: ...
        @typing.overload
        def mkUnattributedRef(self, sym: scala.reflect.api.Symbols.SymbolApi) -> scala.reflect.api.Trees.RefTreeApi: ...
        def mkZero(self, tp: scala.reflect.api.Types.TypeApi) -> scala.reflect.api.Trees.TreeApi: ...
        def stabilize(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...

class package: ...

_NonemptyAttachments__P = typing.TypeVar('_NonemptyAttachments__P')  # <P>
class NonemptyAttachments(Attachments, typing.Generic[_NonemptyAttachments__P]):
    def __init__(self, pos: _NonemptyAttachments__P, all: scala.collection.immutable.Set[typing.Any]): ...
    def all(self) -> scala.collection.immutable.Set[typing.Any]: ...
    def isEmpty(self) -> bool: ...
    def pos(self) -> _NonemptyAttachments__P: ...
    def withPos(self, newPos: _NonemptyAttachments__P) -> 'NonemptyAttachments'[_NonemptyAttachments__P]: ...

class Internals:
    @staticmethod
    def $init$($this: 'Internals') -> None: ...
    def internal(self) -> 'Internals.ContextInternalApi': ...
    class ContextInternalApi(Universe.MacroInternalApi):
        @staticmethod
        def $init$($this: 'Internals.ContextInternalApi') -> None: ...
        def enclosingOwner(self) -> scala.reflect.api.Symbols.SymbolApi: ...
        def transform(self, tree: scala.reflect.api.Trees.TreeApi, transformer: scala.Function2[scala.reflect.api.Trees.TreeApi, 'Internals.ContextInternalApi.TransformApi', scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def typingTransform(self, tree: scala.reflect.api.Trees.TreeApi, transformer: scala.Function2[scala.reflect.api.Trees.TreeApi, 'Internals.ContextInternalApi.TypingTransformApi', scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        @typing.overload
        def typingTransform(self, tree: scala.reflect.api.Trees.TreeApi, owner: scala.reflect.api.Symbols.SymbolApi, transformer: scala.Function2[scala.reflect.api.Trees.TreeApi, 'Internals.ContextInternalApi.TypingTransformApi', scala.reflect.api.Trees.TreeApi]) -> scala.reflect.api.Trees.TreeApi: ...
        class TransformApi:
            def default(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...
            def recur(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...
        class TypingTransformApi(scala.reflect.macros.Internals.ContextInternalApi.TransformApi):
            _atOwner_0__T = typing.TypeVar('_atOwner_0__T')  # <T>
            _atOwner_1__T = typing.TypeVar('_atOwner_1__T')  # <T>
            @typing.overload
            def atOwner(self, owner: scala.reflect.api.Symbols.SymbolApi, op: scala.Function0[_atOwner_0__T]) -> _atOwner_0__T: ...
            @typing.overload
            def atOwner(self, tree: scala.reflect.api.Trees.TreeApi, owner: scala.reflect.api.Symbols.SymbolApi, op: scala.Function0[_atOwner_1__T]) -> _atOwner_1__T: ...
            def currentOwner(self) -> scala.reflect.api.Symbols.SymbolApi: ...
            def typecheck(self, tree: scala.reflect.api.Trees.TreeApi) -> scala.reflect.api.Trees.TreeApi: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.reflect.macros")``.

    Aliases: typing.Type[Aliases]
    Attachments: typing.Type[Attachments]
    Enclosures: typing.Type[Enclosures]
    Evals: typing.Type[Evals]
    ExprUtils: typing.Type[ExprUtils]
    FrontEnds: typing.Type[FrontEnds]
    Infrastructure: typing.Type[Infrastructure]
    Internals: typing.Type[Internals]
    Names: typing.Type[Names]
    NonemptyAttachments: typing.Type[NonemptyAttachments]
    ParseException: typing.Type[ParseException]
    Parsers: typing.Type[Parsers]
    ReificationException: typing.Type[ReificationException]
    Reifiers: typing.Type[Reifiers]
    TypecheckException: typing.Type[TypecheckException]
    Typers: typing.Type[Typers]
    UnexpectedReificationException: typing.Type[UnexpectedReificationException]
    Universe: typing.Type[Universe]
    package: typing.Type[package]
    blackbox: scala.reflect.macros.blackbox.__module_protocol__
    internal: scala.reflect.macros.internal.__module_protocol__
    whitebox: scala.reflect.macros.whitebox.__module_protocol__



import java.io
import java.lang
import java.util
import jpype.protocol
import org.ergoplatform.appkit
import typing



class ApiConfig:
    def __init__(self): ...
    def getApiKey(self) -> java.lang.String: ...
    def getApiUrl(self) -> java.lang.String: ...

class ErgoNodeConfig:
    def __init__(self): ...
    def getNetworkType(self) -> org.ergoplatform.appkit.NetworkType: ...
    def getNodeApi(self) -> ApiConfig: ...
    def getWallet(self) -> 'WalletConfig': ...

class ErgoToolConfig:
    def __init__(self): ...
    def getNode(self) -> ErgoNodeConfig: ...
    def getParameters(self) -> 'ToolParameters': ...
    @typing.overload
    @staticmethod
    def load(file: typing.Union[java.io.File, jpype.protocol.SupportsPath]) -> 'ErgoToolConfig': ...
    @typing.overload
    @staticmethod
    def load(reader: java.io.Reader) -> 'ErgoToolConfig': ...
    @typing.overload
    @staticmethod
    def load(string: typing.Union[java.lang.String, str]) -> 'ErgoToolConfig': ...

class ToolParameters(java.util.HashMap[java.lang.String, java.lang.String]):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> java.lang.String: ...

class WalletConfig:
    def __init__(self): ...
    def getMnemonic(self) -> java.lang.String: ...
    def getMnemonicPassword(self) -> java.lang.String: ...
    def getPassword(self) -> java.lang.String: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.appkit.config")``.

    ApiConfig: typing.Type[ApiConfig]
    ErgoNodeConfig: typing.Type[ErgoNodeConfig]
    ErgoToolConfig: typing.Type[ErgoToolConfig]
    ToolParameters: typing.Type[ToolParameters]
    WalletConfig: typing.Type[WalletConfig]



import java.io
import java.lang
import java.util
import java.util.concurrent
import typing



class AbstractOwnableSynchronizer(java.io.Serializable): ...

class Condition:
    def awaitNanos(self, long: int) -> int: ...
    def awaitUninterruptibly(self) -> None: ...
    def awaitUntil(self, date: java.util.Date) -> bool: ...
    def signal(self) -> None: ...
    def signalAll(self) -> None: ...

class Lock:
    def lock(self) -> None: ...
    def lockInterruptibly(self) -> None: ...
    def newCondition(self) -> Condition: ...
    @typing.overload
    def tryLock(self) -> bool: ...
    @typing.overload
    def tryLock(self, long: int, timeUnit: java.util.concurrent.TimeUnit) -> bool: ...
    def unlock(self) -> None: ...

class LockSupport:
    @staticmethod
    def getBlocker(thread: java.lang.Thread) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def park() -> None: ...
    @typing.overload
    @staticmethod
    def park(object: typing.Any) -> None: ...
    @typing.overload
    @staticmethod
    def parkNanos(object: typing.Any, long: int) -> None: ...
    @typing.overload
    @staticmethod
    def parkNanos(long: int) -> None: ...
    @typing.overload
    @staticmethod
    def parkUntil(object: typing.Any, long: int) -> None: ...
    @typing.overload
    @staticmethod
    def parkUntil(long: int) -> None: ...
    @staticmethod
    def unpark(thread: java.lang.Thread) -> None: ...

class ReadWriteLock:
    def readLock(self) -> Lock: ...
    def writeLock(self) -> Lock: ...

class StampedLock(java.io.Serializable):
    def __init__(self): ...
    def asReadLock(self) -> Lock: ...
    def asReadWriteLock(self) -> ReadWriteLock: ...
    def asWriteLock(self) -> Lock: ...
    def getReadLockCount(self) -> int: ...
    @staticmethod
    def isLockStamp(long: int) -> bool: ...
    @staticmethod
    def isOptimisticReadStamp(long: int) -> bool: ...
    @staticmethod
    def isReadLockStamp(long: int) -> bool: ...
    def isReadLocked(self) -> bool: ...
    @staticmethod
    def isWriteLockStamp(long: int) -> bool: ...
    def isWriteLocked(self) -> bool: ...
    def readLock(self) -> int: ...
    def readLockInterruptibly(self) -> int: ...
    def toString(self) -> str: ...
    def tryConvertToOptimisticRead(self, long: int) -> int: ...
    def tryConvertToReadLock(self, long: int) -> int: ...
    def tryConvertToWriteLock(self, long: int) -> int: ...
    def tryOptimisticRead(self) -> int: ...
    @typing.overload
    def tryReadLock(self) -> int: ...
    @typing.overload
    def tryReadLock(self, long: int, timeUnit: java.util.concurrent.TimeUnit) -> int: ...
    def tryUnlockRead(self) -> bool: ...
    def tryUnlockWrite(self) -> bool: ...
    @typing.overload
    def tryWriteLock(self) -> int: ...
    @typing.overload
    def tryWriteLock(self, long: int, timeUnit: java.util.concurrent.TimeUnit) -> int: ...
    def unlock(self, long: int) -> None: ...
    def unlockRead(self, long: int) -> None: ...
    def unlockWrite(self, long: int) -> None: ...
    def validate(self, long: int) -> bool: ...
    def writeLock(self) -> int: ...
    def writeLockInterruptibly(self) -> int: ...

class AbstractQueuedLongSynchronizer(AbstractOwnableSynchronizer, java.io.Serializable):
    def acquire(self, long: int) -> None: ...
    def acquireInterruptibly(self, long: int) -> None: ...
    def acquireShared(self, long: int) -> None: ...
    def acquireSharedInterruptibly(self, long: int) -> None: ...
    def getExclusiveQueuedThreads(self) -> java.util.Collection[java.lang.Thread]: ...
    def getFirstQueuedThread(self) -> java.lang.Thread: ...
    def getQueueLength(self) -> int: ...
    def getQueuedThreads(self) -> java.util.Collection[java.lang.Thread]: ...
    def getSharedQueuedThreads(self) -> java.util.Collection[java.lang.Thread]: ...
    def getWaitQueueLength(self, conditionObject: 'AbstractQueuedLongSynchronizer.ConditionObject') -> int: ...
    def getWaitingThreads(self, conditionObject: 'AbstractQueuedLongSynchronizer.ConditionObject') -> java.util.Collection[java.lang.Thread]: ...
    def hasContended(self) -> bool: ...
    def hasQueuedPredecessors(self) -> bool: ...
    def hasQueuedThreads(self) -> bool: ...
    def hasWaiters(self, conditionObject: 'AbstractQueuedLongSynchronizer.ConditionObject') -> bool: ...
    def isQueued(self, thread: java.lang.Thread) -> bool: ...
    def owns(self, conditionObject: 'AbstractQueuedLongSynchronizer.ConditionObject') -> bool: ...
    def release(self, long: int) -> bool: ...
    def releaseShared(self, long: int) -> bool: ...
    def toString(self) -> str: ...
    def tryAcquireNanos(self, long: int, long2: int) -> bool: ...
    def tryAcquireSharedNanos(self, long: int, long2: int) -> bool: ...
    class ConditionObject(Condition, java.io.Serializable):
        def __init__(self, abstractQueuedLongSynchronizer: 'AbstractQueuedLongSynchronizer'): ...
        def awaitNanos(self, long: int) -> int: ...
        def awaitUninterruptibly(self) -> None: ...
        def awaitUntil(self, date: java.util.Date) -> bool: ...
        def signal(self) -> None: ...
        def signalAll(self) -> None: ...

class AbstractQueuedSynchronizer(AbstractOwnableSynchronizer, java.io.Serializable):
    def acquire(self, int: int) -> None: ...
    def acquireInterruptibly(self, int: int) -> None: ...
    def acquireShared(self, int: int) -> None: ...
    def acquireSharedInterruptibly(self, int: int) -> None: ...
    def getExclusiveQueuedThreads(self) -> java.util.Collection[java.lang.Thread]: ...
    def getFirstQueuedThread(self) -> java.lang.Thread: ...
    def getQueueLength(self) -> int: ...
    def getQueuedThreads(self) -> java.util.Collection[java.lang.Thread]: ...
    def getSharedQueuedThreads(self) -> java.util.Collection[java.lang.Thread]: ...
    def getWaitQueueLength(self, conditionObject: 'AbstractQueuedSynchronizer.ConditionObject') -> int: ...
    def getWaitingThreads(self, conditionObject: 'AbstractQueuedSynchronizer.ConditionObject') -> java.util.Collection[java.lang.Thread]: ...
    def hasContended(self) -> bool: ...
    def hasQueuedPredecessors(self) -> bool: ...
    def hasQueuedThreads(self) -> bool: ...
    def hasWaiters(self, conditionObject: 'AbstractQueuedSynchronizer.ConditionObject') -> bool: ...
    def isQueued(self, thread: java.lang.Thread) -> bool: ...
    def owns(self, conditionObject: 'AbstractQueuedSynchronizer.ConditionObject') -> bool: ...
    def release(self, int: int) -> bool: ...
    def releaseShared(self, int: int) -> bool: ...
    def toString(self) -> str: ...
    def tryAcquireNanos(self, int: int, long: int) -> bool: ...
    def tryAcquireSharedNanos(self, int: int, long: int) -> bool: ...
    class ConditionObject(Condition, java.io.Serializable):
        def __init__(self, abstractQueuedSynchronizer: 'AbstractQueuedSynchronizer'): ...
        def awaitNanos(self, long: int) -> int: ...
        def awaitUninterruptibly(self) -> None: ...
        def awaitUntil(self, date: java.util.Date) -> bool: ...
        def signal(self) -> None: ...
        def signalAll(self) -> None: ...

class ReentrantLock(Lock, java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, boolean: bool): ...
    def getHoldCount(self) -> int: ...
    def getQueueLength(self) -> int: ...
    def getWaitQueueLength(self, condition: Condition) -> int: ...
    def hasQueuedThread(self, thread: java.lang.Thread) -> bool: ...
    def hasQueuedThreads(self) -> bool: ...
    def hasWaiters(self, condition: Condition) -> bool: ...
    def isFair(self) -> bool: ...
    def isHeldByCurrentThread(self) -> bool: ...
    def isLocked(self) -> bool: ...
    def lock(self) -> None: ...
    def lockInterruptibly(self) -> None: ...
    def newCondition(self) -> Condition: ...
    def toString(self) -> str: ...
    @typing.overload
    def tryLock(self) -> bool: ...
    @typing.overload
    def tryLock(self, long: int, timeUnit: java.util.concurrent.TimeUnit) -> bool: ...
    def unlock(self) -> None: ...

class ReentrantReadWriteLock(ReadWriteLock, java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, boolean: bool): ...
    def getQueueLength(self) -> int: ...
    def getReadHoldCount(self) -> int: ...
    def getReadLockCount(self) -> int: ...
    def getWaitQueueLength(self, condition: Condition) -> int: ...
    def getWriteHoldCount(self) -> int: ...
    def hasQueuedThread(self, thread: java.lang.Thread) -> bool: ...
    def hasQueuedThreads(self) -> bool: ...
    def hasWaiters(self, condition: Condition) -> bool: ...
    def isFair(self) -> bool: ...
    def isWriteLocked(self) -> bool: ...
    def isWriteLockedByCurrentThread(self) -> bool: ...
    def readLock(self) -> 'ReentrantReadWriteLock.ReadLock': ...
    def toString(self) -> str: ...
    def writeLock(self) -> 'ReentrantReadWriteLock.WriteLock': ...
    class ReadLock(Lock, java.io.Serializable):
        def lock(self) -> None: ...
        def lockInterruptibly(self) -> None: ...
        def newCondition(self) -> Condition: ...
        def toString(self) -> str: ...
        @typing.overload
        def tryLock(self) -> bool: ...
        @typing.overload
        def tryLock(self, long: int, timeUnit: java.util.concurrent.TimeUnit) -> bool: ...
        def unlock(self) -> None: ...
    class WriteLock(Lock, java.io.Serializable):
        def getHoldCount(self) -> int: ...
        def isHeldByCurrentThread(self) -> bool: ...
        def lock(self) -> None: ...
        def lockInterruptibly(self) -> None: ...
        def newCondition(self) -> Condition: ...
        def toString(self) -> str: ...
        @typing.overload
        def tryLock(self) -> bool: ...
        @typing.overload
        def tryLock(self, long: int, timeUnit: java.util.concurrent.TimeUnit) -> bool: ...
        def unlock(self) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.util.concurrent.locks")``.

    AbstractOwnableSynchronizer: typing.Type[AbstractOwnableSynchronizer]
    AbstractQueuedLongSynchronizer: typing.Type[AbstractQueuedLongSynchronizer]
    AbstractQueuedSynchronizer: typing.Type[AbstractQueuedSynchronizer]
    Condition: typing.Type[Condition]
    Lock: typing.Type[Lock]
    LockSupport: typing.Type[LockSupport]
    ReadWriteLock: typing.Type[ReadWriteLock]
    ReentrantLock: typing.Type[ReentrantLock]
    ReentrantReadWriteLock: typing.Type[ReentrantReadWriteLock]
    StampedLock: typing.Type[StampedLock]



import datetime
import java.io
import java.lang
import java.time.chrono
import java.time.format
import java.time.temporal
import java.time.zone
import java.util
import java.util.stream
import typing



class Clock:
    def equals(self, object: typing.Any) -> bool: ...
    @staticmethod
    def fixed(instant: typing.Union['Instant', datetime.datetime], zoneId: 'ZoneId') -> 'Clock': ...
    def getZone(self) -> 'ZoneId': ...
    def hashCode(self) -> int: ...
    def instant(self) -> 'Instant': ...
    def millis(self) -> int: ...
    @staticmethod
    def offset(clock: 'Clock', duration: 'Duration') -> 'Clock': ...
    @staticmethod
    def system(zoneId: 'ZoneId') -> 'Clock': ...
    @staticmethod
    def systemDefaultZone() -> 'Clock': ...
    @staticmethod
    def systemUTC() -> 'Clock': ...
    @staticmethod
    def tick(clock: 'Clock', duration: 'Duration') -> 'Clock': ...
    @staticmethod
    def tickMillis(zoneId: 'ZoneId') -> 'Clock': ...
    @staticmethod
    def tickMinutes(zoneId: 'ZoneId') -> 'Clock': ...
    @staticmethod
    def tickSeconds(zoneId: 'ZoneId') -> 'Clock': ...
    def withZone(self, zoneId: 'ZoneId') -> 'Clock': ...

class DateTimeException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...

class DayOfWeek(java.lang.Enum['DayOfWeek'], java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    MONDAY: typing.ClassVar['DayOfWeek'] = ...
    TUESDAY: typing.ClassVar['DayOfWeek'] = ...
    WEDNESDAY: typing.ClassVar['DayOfWeek'] = ...
    THURSDAY: typing.ClassVar['DayOfWeek'] = ...
    FRIDAY: typing.ClassVar['DayOfWeek'] = ...
    SATURDAY: typing.ClassVar['DayOfWeek'] = ...
    SUNDAY: typing.ClassVar['DayOfWeek'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getValue(self) -> int: ...
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    def minus(self, long: int) -> 'DayOfWeek': ...
    @staticmethod
    def of(int: int) -> 'DayOfWeek': ...
    def plus(self, long: int) -> 'DayOfWeek': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'DayOfWeek': ...
    @staticmethod
    def values() -> typing.List['DayOfWeek']: ...

class Duration(java.time.temporal.TemporalAmount, java.lang.Comparable['Duration'], java.io.Serializable):
    ZERO: typing.ClassVar['Duration'] = ...
    def abs(self) -> 'Duration': ...
    def addTo(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    @staticmethod
    def between(temporal: java.time.temporal.Temporal, temporal2: java.time.temporal.Temporal) -> 'Duration': ...
    def compareTo(self, duration: 'Duration') -> int: ...
    @typing.overload
    def dividedBy(self, long: int) -> 'Duration': ...
    @typing.overload
    def dividedBy(self, duration: 'Duration') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def get(self, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def getNano(self) -> int: ...
    def getSeconds(self) -> int: ...
    def getUnits(self) -> java.util.List[java.time.temporal.TemporalUnit]: ...
    def hashCode(self) -> int: ...
    def isNegative(self) -> bool: ...
    def isZero(self) -> bool: ...
    @typing.overload
    def minus(self, duration: 'Duration') -> 'Duration': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'Duration': ...
    def minusDays(self, long: int) -> 'Duration': ...
    def minusHours(self, long: int) -> 'Duration': ...
    def minusMillis(self, long: int) -> 'Duration': ...
    def minusMinutes(self, long: int) -> 'Duration': ...
    def minusNanos(self, long: int) -> 'Duration': ...
    def minusSeconds(self, long: int) -> 'Duration': ...
    def multipliedBy(self, long: int) -> 'Duration': ...
    def negated(self) -> 'Duration': ...
    @staticmethod
    def of(long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'Duration': ...
    @staticmethod
    def ofDays(long: int) -> 'Duration': ...
    @staticmethod
    def ofHours(long: int) -> 'Duration': ...
    @staticmethod
    def ofMillis(long: int) -> 'Duration': ...
    @staticmethod
    def ofMinutes(long: int) -> 'Duration': ...
    @staticmethod
    def ofNanos(long: int) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def ofSeconds(long: int) -> 'Duration': ...
    @typing.overload
    @staticmethod
    def ofSeconds(long: int, long2: int) -> 'Duration': ...
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'Duration': ...
    @typing.overload
    def plus(self, duration: 'Duration') -> 'Duration': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'Duration': ...
    def plusDays(self, long: int) -> 'Duration': ...
    def plusHours(self, long: int) -> 'Duration': ...
    def plusMillis(self, long: int) -> 'Duration': ...
    def plusMinutes(self, long: int) -> 'Duration': ...
    def plusNanos(self, long: int) -> 'Duration': ...
    def plusSeconds(self, long: int) -> 'Duration': ...
    def subtractFrom(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def toDays(self) -> int: ...
    def toDaysPart(self) -> int: ...
    def toHours(self) -> int: ...
    def toHoursPart(self) -> int: ...
    def toMillis(self) -> int: ...
    def toMillisPart(self) -> int: ...
    def toMinutes(self) -> int: ...
    def toMinutesPart(self) -> int: ...
    def toNanos(self) -> int: ...
    def toNanosPart(self) -> int: ...
    def toSeconds(self) -> int: ...
    def toSecondsPart(self) -> int: ...
    def toString(self) -> str: ...
    def truncatedTo(self, temporalUnit: java.time.temporal.TemporalUnit) -> 'Duration': ...
    def withNanos(self, int: int) -> 'Duration': ...
    def withSeconds(self, long: int) -> 'Duration': ...

class Instant(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['Instant'], java.io.Serializable):
    EPOCH: typing.ClassVar['Instant'] = ...
    MIN: typing.ClassVar['Instant'] = ...
    MAX: typing.ClassVar['Instant'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atOffset(self, zoneOffset: 'ZoneOffset') -> 'OffsetDateTime': ...
    def atZone(self, zoneId: 'ZoneId') -> 'ZonedDateTime': ...
    def compareTo(self, instant: typing.Union['Instant', datetime.datetime]) -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getEpochSecond(self) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getNano(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, instant: typing.Union['Instant', datetime.datetime]) -> bool: ...
    def isBefore(self, instant: typing.Union['Instant', datetime.datetime]) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'Instant': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'Instant': ...
    def minusMillis(self, long: int) -> 'Instant': ...
    def minusNanos(self, long: int) -> 'Instant': ...
    def minusSeconds(self, long: int) -> 'Instant': ...
    @typing.overload
    @staticmethod
    def now() -> 'Instant': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'Instant': ...
    @staticmethod
    def ofEpochMilli(long: int) -> 'Instant': ...
    @typing.overload
    @staticmethod
    def ofEpochSecond(long: int) -> 'Instant': ...
    @typing.overload
    @staticmethod
    def ofEpochSecond(long: int, long2: int) -> 'Instant': ...
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'Instant': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'Instant': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'Instant': ...
    def plusMillis(self, long: int) -> 'Instant': ...
    def plusNanos(self, long: int) -> 'Instant': ...
    def plusSeconds(self, long: int) -> 'Instant': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochMilli(self) -> int: ...
    def toString(self) -> str: ...
    def truncatedTo(self, temporalUnit: java.time.temporal.TemporalUnit) -> 'Instant': ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...

class LocalDate(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.time.chrono.ChronoLocalDate, java.io.Serializable):
    MIN: typing.ClassVar['LocalDate'] = ...
    MAX: typing.ClassVar['LocalDate'] = ...
    EPOCH: typing.ClassVar['LocalDate'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    @typing.overload
    def atStartOfDay(self) -> 'LocalDateTime': ...
    @typing.overload
    def atStartOfDay(self, zoneId: 'ZoneId') -> 'ZonedDateTime': ...
    @typing.overload
    def atTime(self, int: int, int2: int) -> 'LocalDateTime': ...
    @typing.overload
    def atTime(self, int: int, int2: int, int3: int) -> 'LocalDateTime': ...
    @typing.overload
    def atTime(self, int: int, int2: int, int3: int, int4: int) -> 'LocalDateTime': ...
    @typing.overload
    def atTime(self, localTime: 'LocalTime') -> 'LocalDateTime': ...
    @typing.overload
    def atTime(self, offsetTime: 'OffsetTime') -> 'OffsetDateTime': ...
    def compareTo(self, chronoLocalDate: java.time.chrono.ChronoLocalDate) -> int: ...
    @typing.overload
    def datesUntil(self, localDate: 'LocalDate') -> java.util.stream.Stream['LocalDate']: ...
    @typing.overload
    def datesUntil(self, localDate: 'LocalDate', period: 'Period') -> java.util.stream.Stream['LocalDate']: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getChronology(self) -> java.time.chrono.IsoChronology: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getEra(self) -> java.time.chrono.IsoEra: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMonth(self) -> 'Month': ...
    def getMonthValue(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, chronoLocalDate: java.time.chrono.ChronoLocalDate) -> bool: ...
    def isBefore(self, chronoLocalDate: java.time.chrono.ChronoLocalDate) -> bool: ...
    def isEqual(self, chronoLocalDate: java.time.chrono.ChronoLocalDate) -> bool: ...
    def isLeapYear(self) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'LocalDate': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalDate': ...
    def minusDays(self, long: int) -> 'LocalDate': ...
    def minusMonths(self, long: int) -> 'LocalDate': ...
    def minusWeeks(self, long: int) -> 'LocalDate': ...
    def minusYears(self, long: int) -> 'LocalDate': ...
    @typing.overload
    @staticmethod
    def now() -> 'LocalDate': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'LocalDate': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'LocalDate': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int) -> 'LocalDate': ...
    @typing.overload
    @staticmethod
    def of(int: int, month: 'Month', int2: int) -> 'LocalDate': ...
    @staticmethod
    def ofEpochDay(long: int) -> 'LocalDate': ...
    @staticmethod
    def ofInstant(instant: typing.Union[Instant, datetime.datetime], zoneId: 'ZoneId') -> 'LocalDate': ...
    @staticmethod
    def ofYearDay(int: int, int2: int) -> 'LocalDate': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'LocalDate': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'LocalDate': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'LocalDate': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalDate': ...
    def plusDays(self, long: int) -> 'LocalDate': ...
    def plusMonths(self, long: int) -> 'LocalDate': ...
    def plusWeeks(self, long: int) -> 'LocalDate': ...
    def plusYears(self, long: int) -> 'LocalDate': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochDay(self) -> int: ...
    def toEpochSecond(self, localTime: 'LocalTime', zoneOffset: 'ZoneOffset') -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def until(self, chronoLocalDate: java.time.chrono.ChronoLocalDate) -> 'Period': ...
    @typing.overload
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def withDayOfMonth(self, int: int) -> 'LocalDate': ...
    def withDayOfYear(self, int: int) -> 'LocalDate': ...
    def withMonth(self, int: int) -> 'LocalDate': ...
    def withYear(self, int: int) -> 'LocalDate': ...

class LocalDateTime(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.time.chrono.ChronoLocalDateTime[LocalDate], java.io.Serializable):
    MIN: typing.ClassVar['LocalDateTime'] = ...
    MAX: typing.ClassVar['LocalDateTime'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atOffset(self, zoneOffset: 'ZoneOffset') -> 'OffsetDateTime': ...
    def atZone(self, zoneId: 'ZoneId') -> 'ZonedDateTime': ...
    def compareTo(self, chronoLocalDateTime: java.time.chrono.ChronoLocalDateTime[typing.Any]) -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> 'Month': ...
    def getMonthValue(self) -> int: ...
    def getNano(self) -> int: ...
    def getSecond(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, chronoLocalDateTime: java.time.chrono.ChronoLocalDateTime[typing.Any]) -> bool: ...
    def isBefore(self, chronoLocalDateTime: java.time.chrono.ChronoLocalDateTime[typing.Any]) -> bool: ...
    def isEqual(self, chronoLocalDateTime: java.time.chrono.ChronoLocalDateTime[typing.Any]) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'LocalDateTime': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalDateTime': ...
    def minusDays(self, long: int) -> 'LocalDateTime': ...
    def minusHours(self, long: int) -> 'LocalDateTime': ...
    def minusMinutes(self, long: int) -> 'LocalDateTime': ...
    def minusMonths(self, long: int) -> 'LocalDateTime': ...
    def minusNanos(self, long: int) -> 'LocalDateTime': ...
    def minusSeconds(self, long: int) -> 'LocalDateTime': ...
    def minusWeeks(self, long: int) -> 'LocalDateTime': ...
    def minusYears(self, long: int) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def now() -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int, int4: int, int5: int) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int, int4: int, int5: int, int6: int) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int, int4: int, int5: int, int6: int, int7: int) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, month: 'Month', int2: int, int3: int, int4: int) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, month: 'Month', int2: int, int3: int, int4: int, int5: int) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, month: 'Month', int2: int, int3: int, int4: int, int5: int, int6: int) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def of(localDate: LocalDate, localTime: 'LocalTime') -> 'LocalDateTime': ...
    @staticmethod
    def ofEpochSecond(long: int, int: int, zoneOffset: 'ZoneOffset') -> 'LocalDateTime': ...
    @staticmethod
    def ofInstant(instant: typing.Union[Instant, datetime.datetime], zoneId: 'ZoneId') -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'LocalDateTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'LocalDateTime': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'LocalDateTime': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalDateTime': ...
    def plusDays(self, long: int) -> 'LocalDateTime': ...
    def plusHours(self, long: int) -> 'LocalDateTime': ...
    def plusMinutes(self, long: int) -> 'LocalDateTime': ...
    def plusMonths(self, long: int) -> 'LocalDateTime': ...
    def plusNanos(self, long: int) -> 'LocalDateTime': ...
    def plusSeconds(self, long: int) -> 'LocalDateTime': ...
    def plusWeeks(self, long: int) -> 'LocalDateTime': ...
    def plusYears(self, long: int) -> 'LocalDateTime': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toLocalDate(self) -> LocalDate: ...
    def toLocalTime(self) -> 'LocalTime': ...
    def toString(self) -> str: ...
    def truncatedTo(self, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalDateTime': ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def withDayOfMonth(self, int: int) -> 'LocalDateTime': ...
    def withDayOfYear(self, int: int) -> 'LocalDateTime': ...
    def withHour(self, int: int) -> 'LocalDateTime': ...
    def withMinute(self, int: int) -> 'LocalDateTime': ...
    def withMonth(self, int: int) -> 'LocalDateTime': ...
    def withNano(self, int: int) -> 'LocalDateTime': ...
    def withSecond(self, int: int) -> 'LocalDateTime': ...
    def withYear(self, int: int) -> 'LocalDateTime': ...

class LocalTime(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['LocalTime'], java.io.Serializable):
    MIN: typing.ClassVar['LocalTime'] = ...
    MAX: typing.ClassVar['LocalTime'] = ...
    MIDNIGHT: typing.ClassVar['LocalTime'] = ...
    NOON: typing.ClassVar['LocalTime'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atDate(self, localDate: LocalDate) -> LocalDateTime: ...
    def atOffset(self, zoneOffset: 'ZoneOffset') -> 'OffsetTime': ...
    def compareTo(self, localTime: 'LocalTime') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMinute(self) -> int: ...
    def getNano(self) -> int: ...
    def getSecond(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, localTime: 'LocalTime') -> bool: ...
    def isBefore(self, localTime: 'LocalTime') -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'LocalTime': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalTime': ...
    def minusHours(self, long: int) -> 'LocalTime': ...
    def minusMinutes(self, long: int) -> 'LocalTime': ...
    def minusNanos(self, long: int) -> 'LocalTime': ...
    def minusSeconds(self, long: int) -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def now() -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int) -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int) -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int, int4: int) -> 'LocalTime': ...
    @staticmethod
    def ofInstant(instant: typing.Union[Instant, datetime.datetime], zoneId: 'ZoneId') -> 'LocalTime': ...
    @staticmethod
    def ofNanoOfDay(long: int) -> 'LocalTime': ...
    @staticmethod
    def ofSecondOfDay(long: int) -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'LocalTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'LocalTime': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'LocalTime': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalTime': ...
    def plusHours(self, long: int) -> 'LocalTime': ...
    def plusMinutes(self, long: int) -> 'LocalTime': ...
    def plusNanos(self, long: int) -> 'LocalTime': ...
    def plusSeconds(self, long: int) -> 'LocalTime': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochSecond(self, localDate: LocalDate, zoneOffset: 'ZoneOffset') -> int: ...
    def toNanoOfDay(self) -> int: ...
    def toSecondOfDay(self) -> int: ...
    def toString(self) -> str: ...
    def truncatedTo(self, temporalUnit: java.time.temporal.TemporalUnit) -> 'LocalTime': ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def withHour(self, int: int) -> 'LocalTime': ...
    def withMinute(self, int: int) -> 'LocalTime': ...
    def withNano(self, int: int) -> 'LocalTime': ...
    def withSecond(self, int: int) -> 'LocalTime': ...

class Month(java.lang.Enum['Month'], java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster):
    JANUARY: typing.ClassVar['Month'] = ...
    FEBRUARY: typing.ClassVar['Month'] = ...
    MARCH: typing.ClassVar['Month'] = ...
    APRIL: typing.ClassVar['Month'] = ...
    MAY: typing.ClassVar['Month'] = ...
    JUNE: typing.ClassVar['Month'] = ...
    JULY: typing.ClassVar['Month'] = ...
    AUGUST: typing.ClassVar['Month'] = ...
    SEPTEMBER: typing.ClassVar['Month'] = ...
    OCTOBER: typing.ClassVar['Month'] = ...
    NOVEMBER: typing.ClassVar['Month'] = ...
    DECEMBER: typing.ClassVar['Month'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def firstDayOfYear(self, boolean: bool) -> int: ...
    def firstMonthOfQuarter(self) -> 'Month': ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getValue(self) -> int: ...
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    def length(self, boolean: bool) -> int: ...
    def maxLength(self) -> int: ...
    def minLength(self) -> int: ...
    def minus(self, long: int) -> 'Month': ...
    @staticmethod
    def of(int: int) -> 'Month': ...
    def plus(self, long: int) -> 'Month': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'Month': ...
    @staticmethod
    def values() -> typing.List['Month']: ...

class MonthDay(java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster, java.lang.Comparable['MonthDay'], java.io.Serializable):
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atYear(self, int: int) -> LocalDate: ...
    def compareTo(self, monthDay: 'MonthDay') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, monthDay: 'MonthDay') -> bool: ...
    def isBefore(self, monthDay: 'MonthDay') -> bool: ...
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    def isValidYear(self, int: int) -> bool: ...
    @typing.overload
    @staticmethod
    def now() -> 'MonthDay': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'MonthDay': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'MonthDay': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int) -> 'MonthDay': ...
    @typing.overload
    @staticmethod
    def of(month: Month, int: int) -> 'MonthDay': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'MonthDay': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'MonthDay': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    def withDayOfMonth(self, int: int) -> 'MonthDay': ...
    def withMonth(self, int: int) -> 'MonthDay': ...

class OffsetDateTime(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['OffsetDateTime'], java.io.Serializable):
    MIN: typing.ClassVar['OffsetDateTime'] = ...
    MAX: typing.ClassVar['OffsetDateTime'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atZoneSameInstant(self, zoneId: 'ZoneId') -> 'ZonedDateTime': ...
    def atZoneSimilarLocal(self, zoneId: 'ZoneId') -> 'ZonedDateTime': ...
    def compareTo(self, offsetDateTime: 'OffsetDateTime') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getNano(self) -> int: ...
    def getOffset(self) -> 'ZoneOffset': ...
    def getSecond(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, offsetDateTime: 'OffsetDateTime') -> bool: ...
    def isBefore(self, offsetDateTime: 'OffsetDateTime') -> bool: ...
    def isEqual(self, offsetDateTime: 'OffsetDateTime') -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'OffsetDateTime': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'OffsetDateTime': ...
    def minusDays(self, long: int) -> 'OffsetDateTime': ...
    def minusHours(self, long: int) -> 'OffsetDateTime': ...
    def minusMinutes(self, long: int) -> 'OffsetDateTime': ...
    def minusMonths(self, long: int) -> 'OffsetDateTime': ...
    def minusNanos(self, long: int) -> 'OffsetDateTime': ...
    def minusSeconds(self, long: int) -> 'OffsetDateTime': ...
    def minusWeeks(self, long: int) -> 'OffsetDateTime': ...
    def minusYears(self, long: int) -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def now() -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int, int4: int, int5: int, int6: int, int7: int, zoneOffset: 'ZoneOffset') -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def of(localDate: LocalDate, localTime: LocalTime, zoneOffset: 'ZoneOffset') -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def of(localDateTime: LocalDateTime, zoneOffset: 'ZoneOffset') -> 'OffsetDateTime': ...
    @staticmethod
    def ofInstant(instant: typing.Union[Instant, datetime.datetime], zoneId: 'ZoneId') -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'OffsetDateTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'OffsetDateTime': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'OffsetDateTime': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'OffsetDateTime': ...
    def plusDays(self, long: int) -> 'OffsetDateTime': ...
    def plusHours(self, long: int) -> 'OffsetDateTime': ...
    def plusMinutes(self, long: int) -> 'OffsetDateTime': ...
    def plusMonths(self, long: int) -> 'OffsetDateTime': ...
    def plusNanos(self, long: int) -> 'OffsetDateTime': ...
    def plusSeconds(self, long: int) -> 'OffsetDateTime': ...
    def plusWeeks(self, long: int) -> 'OffsetDateTime': ...
    def plusYears(self, long: int) -> 'OffsetDateTime': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    @staticmethod
    def timeLineOrder() -> java.util.Comparator['OffsetDateTime']: ...
    def toEpochSecond(self) -> int: ...
    def toInstant(self) -> Instant: ...
    def toLocalDate(self) -> LocalDate: ...
    def toLocalDateTime(self) -> LocalDateTime: ...
    def toLocalTime(self) -> LocalTime: ...
    def toOffsetTime(self) -> 'OffsetTime': ...
    def toString(self) -> str: ...
    def toZonedDateTime(self) -> 'ZonedDateTime': ...
    def truncatedTo(self, temporalUnit: java.time.temporal.TemporalUnit) -> 'OffsetDateTime': ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def withDayOfMonth(self, int: int) -> 'OffsetDateTime': ...
    def withDayOfYear(self, int: int) -> 'OffsetDateTime': ...
    def withHour(self, int: int) -> 'OffsetDateTime': ...
    def withMinute(self, int: int) -> 'OffsetDateTime': ...
    def withMonth(self, int: int) -> 'OffsetDateTime': ...
    def withNano(self, int: int) -> 'OffsetDateTime': ...
    def withOffsetSameInstant(self, zoneOffset: 'ZoneOffset') -> 'OffsetDateTime': ...
    def withOffsetSameLocal(self, zoneOffset: 'ZoneOffset') -> 'OffsetDateTime': ...
    def withSecond(self, int: int) -> 'OffsetDateTime': ...
    def withYear(self, int: int) -> 'OffsetDateTime': ...

class OffsetTime(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['OffsetTime'], java.io.Serializable):
    MIN: typing.ClassVar['OffsetTime'] = ...
    MAX: typing.ClassVar['OffsetTime'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atDate(self, localDate: LocalDate) -> OffsetDateTime: ...
    def compareTo(self, offsetTime: 'OffsetTime') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMinute(self) -> int: ...
    def getNano(self) -> int: ...
    def getOffset(self) -> 'ZoneOffset': ...
    def getSecond(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, offsetTime: 'OffsetTime') -> bool: ...
    def isBefore(self, offsetTime: 'OffsetTime') -> bool: ...
    def isEqual(self, offsetTime: 'OffsetTime') -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'OffsetTime': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'OffsetTime': ...
    def minusHours(self, long: int) -> 'OffsetTime': ...
    def minusMinutes(self, long: int) -> 'OffsetTime': ...
    def minusNanos(self, long: int) -> 'OffsetTime': ...
    def minusSeconds(self, long: int) -> 'OffsetTime': ...
    @typing.overload
    @staticmethod
    def now() -> 'OffsetTime': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'OffsetTime': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'OffsetTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int, int4: int, zoneOffset: 'ZoneOffset') -> 'OffsetTime': ...
    @typing.overload
    @staticmethod
    def of(localTime: LocalTime, zoneOffset: 'ZoneOffset') -> 'OffsetTime': ...
    @staticmethod
    def ofInstant(instant: typing.Union[Instant, datetime.datetime], zoneId: 'ZoneId') -> 'OffsetTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'OffsetTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'OffsetTime': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'OffsetTime': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'OffsetTime': ...
    def plusHours(self, long: int) -> 'OffsetTime': ...
    def plusMinutes(self, long: int) -> 'OffsetTime': ...
    def plusNanos(self, long: int) -> 'OffsetTime': ...
    def plusSeconds(self, long: int) -> 'OffsetTime': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toEpochSecond(self, localDate: LocalDate) -> int: ...
    def toLocalTime(self) -> LocalTime: ...
    def toString(self) -> str: ...
    def truncatedTo(self, temporalUnit: java.time.temporal.TemporalUnit) -> 'OffsetTime': ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def withHour(self, int: int) -> 'OffsetTime': ...
    def withMinute(self, int: int) -> 'OffsetTime': ...
    def withNano(self, int: int) -> 'OffsetTime': ...
    def withOffsetSameInstant(self, zoneOffset: 'ZoneOffset') -> 'OffsetTime': ...
    def withOffsetSameLocal(self, zoneOffset: 'ZoneOffset') -> 'OffsetTime': ...
    def withSecond(self, int: int) -> 'OffsetTime': ...

class Period(java.time.chrono.ChronoPeriod, java.io.Serializable):
    ZERO: typing.ClassVar['Period'] = ...
    def addTo(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    @staticmethod
    def between(localDate: LocalDate, localDate2: LocalDate) -> 'Period': ...
    def equals(self, object: typing.Any) -> bool: ...
    def get(self, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def getChronology(self) -> java.time.chrono.IsoChronology: ...
    def getDays(self) -> int: ...
    def getMonths(self) -> int: ...
    def getUnits(self) -> java.util.List[java.time.temporal.TemporalUnit]: ...
    def getYears(self) -> int: ...
    def hashCode(self) -> int: ...
    def isNegative(self) -> bool: ...
    def isZero(self) -> bool: ...
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'Period': ...
    def minusDays(self, long: int) -> 'Period': ...
    def minusMonths(self, long: int) -> 'Period': ...
    def minusYears(self, long: int) -> 'Period': ...
    def multipliedBy(self, int: int) -> 'Period': ...
    def negated(self) -> 'Period': ...
    def normalized(self) -> 'Period': ...
    @staticmethod
    def of(int: int, int2: int, int3: int) -> 'Period': ...
    @staticmethod
    def ofDays(int: int) -> 'Period': ...
    @staticmethod
    def ofMonths(int: int) -> 'Period': ...
    @staticmethod
    def ofWeeks(int: int) -> 'Period': ...
    @staticmethod
    def ofYears(int: int) -> 'Period': ...
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'Period': ...
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'Period': ...
    def plusDays(self, long: int) -> 'Period': ...
    def plusMonths(self, long: int) -> 'Period': ...
    def plusYears(self, long: int) -> 'Period': ...
    def subtractFrom(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def toString(self) -> str: ...
    def toTotalMonths(self) -> int: ...
    def withDays(self, int: int) -> 'Period': ...
    def withMonths(self, int: int) -> 'Period': ...
    def withYears(self, int: int) -> 'Period': ...

class Year(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['Year'], java.io.Serializable):
    MIN_VALUE: typing.ClassVar[int] = ...
    MAX_VALUE: typing.ClassVar[int] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atDay(self, int: int) -> LocalDate: ...
    @typing.overload
    def atMonth(self, int: int) -> 'YearMonth': ...
    @typing.overload
    def atMonth(self, month: Month) -> 'YearMonth': ...
    def atMonthDay(self, monthDay: MonthDay) -> LocalDate: ...
    def compareTo(self, year: 'Year') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getValue(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, year: 'Year') -> bool: ...
    def isBefore(self, year: 'Year') -> bool: ...
    @typing.overload
    def isLeap(self) -> bool: ...
    @typing.overload
    @staticmethod
    def isLeap(long: int) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    def isValidMonthDay(self, monthDay: MonthDay) -> bool: ...
    def length(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'Year': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'Year': ...
    def minusYears(self, long: int) -> 'Year': ...
    @typing.overload
    @staticmethod
    def now() -> 'Year': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'Year': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'Year': ...
    @staticmethod
    def of(int: int) -> 'Year': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'Year': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'Year': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'Year': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'Year': ...
    def plusYears(self, long: int) -> 'Year': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...

class YearMonth(java.time.temporal.Temporal, java.time.temporal.TemporalAdjuster, java.lang.Comparable['YearMonth'], java.io.Serializable):
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def atDay(self, int: int) -> LocalDate: ...
    def atEndOfMonth(self) -> LocalDate: ...
    def compareTo(self, yearMonth: 'YearMonth') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getYear(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAfter(self, yearMonth: 'YearMonth') -> bool: ...
    def isBefore(self, yearMonth: 'YearMonth') -> bool: ...
    def isLeapYear(self) -> bool: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    def isValidDay(self, int: int) -> bool: ...
    def lengthOfMonth(self) -> int: ...
    def lengthOfYear(self) -> int: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'YearMonth': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'YearMonth': ...
    def minusMonths(self, long: int) -> 'YearMonth': ...
    def minusYears(self, long: int) -> 'YearMonth': ...
    @typing.overload
    @staticmethod
    def now() -> 'YearMonth': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'YearMonth': ...
    @typing.overload
    @staticmethod
    def now(zoneId: 'ZoneId') -> 'YearMonth': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int) -> 'YearMonth': ...
    @typing.overload
    @staticmethod
    def of(int: int, month: Month) -> 'YearMonth': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'YearMonth': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'YearMonth': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'YearMonth': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'YearMonth': ...
    def plusMonths(self, long: int) -> 'YearMonth': ...
    def plusYears(self, long: int) -> 'YearMonth': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def withMonth(self, int: int) -> 'YearMonth': ...
    def withYear(self, int: int) -> 'YearMonth': ...

class ZoneId(java.io.Serializable):
    SHORT_IDS: typing.ClassVar[java.util.Map] = ...
    def equals(self, object: typing.Any) -> bool: ...
    @staticmethod
    def getAvailableZoneIds() -> java.util.Set[str]: ...
    def getDisplayName(self, textStyle: java.time.format.TextStyle, locale: java.util.Locale) -> str: ...
    def getId(self) -> str: ...
    def getRules(self) -> java.time.zone.ZoneRules: ...
    def hashCode(self) -> int: ...
    def normalized(self) -> 'ZoneId': ...
    @typing.overload
    @staticmethod
    def of(string: str) -> 'ZoneId': ...
    @typing.overload
    @staticmethod
    def of(string: str, map: typing.Union[java.util.Map[str, str], typing.Mapping[str, str]]) -> 'ZoneId': ...
    @staticmethod
    def ofOffset(string: str, zoneOffset: 'ZoneOffset') -> 'ZoneId': ...
    @staticmethod
    def systemDefault() -> 'ZoneId': ...
    def toString(self) -> str: ...

class ZonedDateTime(java.time.temporal.Temporal, java.time.chrono.ChronoZonedDateTime[LocalDate], java.io.Serializable):
    def equals(self, object: typing.Any) -> bool: ...
    def format(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> str: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getDayOfMonth(self) -> int: ...
    def getDayOfWeek(self) -> DayOfWeek: ...
    def getDayOfYear(self) -> int: ...
    def getHour(self) -> int: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getMinute(self) -> int: ...
    def getMonth(self) -> Month: ...
    def getMonthValue(self) -> int: ...
    def getNano(self) -> int: ...
    def getOffset(self) -> 'ZoneOffset': ...
    def getSecond(self) -> int: ...
    def getYear(self) -> int: ...
    def getZone(self) -> ZoneId: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    def isSupported(self, temporalUnit: java.time.temporal.TemporalUnit) -> bool: ...
    @typing.overload
    def minus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ZonedDateTime': ...
    @typing.overload
    def minus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ZonedDateTime': ...
    def minusDays(self, long: int) -> 'ZonedDateTime': ...
    def minusHours(self, long: int) -> 'ZonedDateTime': ...
    def minusMinutes(self, long: int) -> 'ZonedDateTime': ...
    def minusMonths(self, long: int) -> 'ZonedDateTime': ...
    def minusNanos(self, long: int) -> 'ZonedDateTime': ...
    def minusSeconds(self, long: int) -> 'ZonedDateTime': ...
    def minusWeeks(self, long: int) -> 'ZonedDateTime': ...
    def minusYears(self, long: int) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def now() -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def now(clock: Clock) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def now(zoneId: ZoneId) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def of(int: int, int2: int, int3: int, int4: int, int5: int, int6: int, int7: int, zoneId: ZoneId) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def of(localDate: LocalDate, localTime: LocalTime, zoneId: ZoneId) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def of(localDateTime: LocalDateTime, zoneId: ZoneId) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def ofInstant(instant: typing.Union[Instant, datetime.datetime], zoneId: ZoneId) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def ofInstant(localDateTime: LocalDateTime, zoneOffset: 'ZoneOffset', zoneId: ZoneId) -> 'ZonedDateTime': ...
    @staticmethod
    def ofLocal(localDateTime: LocalDateTime, zoneId: ZoneId, zoneOffset: 'ZoneOffset') -> 'ZonedDateTime': ...
    @staticmethod
    def ofStrict(localDateTime: LocalDateTime, zoneOffset: 'ZoneOffset', zoneId: ZoneId) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str]) -> 'ZonedDateTime': ...
    @typing.overload
    @staticmethod
    def parse(charSequence: typing.Union[java.lang.CharSequence, str], dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'ZonedDateTime': ...
    @typing.overload
    def plus(self, temporalAmount: java.time.temporal.TemporalAmount) -> 'ZonedDateTime': ...
    @typing.overload
    def plus(self, long: int, temporalUnit: java.time.temporal.TemporalUnit) -> 'ZonedDateTime': ...
    def plusDays(self, long: int) -> 'ZonedDateTime': ...
    def plusHours(self, long: int) -> 'ZonedDateTime': ...
    def plusMinutes(self, long: int) -> 'ZonedDateTime': ...
    def plusMonths(self, long: int) -> 'ZonedDateTime': ...
    def plusNanos(self, long: int) -> 'ZonedDateTime': ...
    def plusSeconds(self, long: int) -> 'ZonedDateTime': ...
    def plusWeeks(self, long: int) -> 'ZonedDateTime': ...
    def plusYears(self, long: int) -> 'ZonedDateTime': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toLocalDate(self) -> LocalDate: ...
    def toLocalDateTime(self) -> LocalDateTime: ...
    def toLocalTime(self) -> LocalTime: ...
    def toOffsetDateTime(self) -> OffsetDateTime: ...
    def toString(self) -> str: ...
    def truncatedTo(self, temporalUnit: java.time.temporal.TemporalUnit) -> 'ZonedDateTime': ...
    def until(self, temporal: java.time.temporal.Temporal, temporalUnit: java.time.temporal.TemporalUnit) -> int: ...
    def withDayOfMonth(self, int: int) -> 'ZonedDateTime': ...
    def withDayOfYear(self, int: int) -> 'ZonedDateTime': ...
    def withEarlierOffsetAtOverlap(self) -> 'ZonedDateTime': ...
    def withFixedOffsetZone(self) -> 'ZonedDateTime': ...
    def withHour(self, int: int) -> 'ZonedDateTime': ...
    def withLaterOffsetAtOverlap(self) -> 'ZonedDateTime': ...
    def withMinute(self, int: int) -> 'ZonedDateTime': ...
    def withMonth(self, int: int) -> 'ZonedDateTime': ...
    def withNano(self, int: int) -> 'ZonedDateTime': ...
    def withSecond(self, int: int) -> 'ZonedDateTime': ...
    def withYear(self, int: int) -> 'ZonedDateTime': ...
    def withZoneSameInstant(self, zoneId: ZoneId) -> 'ZonedDateTime': ...
    def withZoneSameLocal(self, zoneId: ZoneId) -> 'ZonedDateTime': ...

class ZoneOffset(ZoneId, java.time.temporal.TemporalAccessor, java.time.temporal.TemporalAdjuster, java.lang.Comparable['ZoneOffset'], java.io.Serializable):
    UTC: typing.ClassVar['ZoneOffset'] = ...
    MIN: typing.ClassVar['ZoneOffset'] = ...
    MAX: typing.ClassVar['ZoneOffset'] = ...
    def adjustInto(self, temporal: java.time.temporal.Temporal) -> java.time.temporal.Temporal: ...
    def compareTo(self, zoneOffset: 'ZoneOffset') -> int: ...
    def equals(self, object: typing.Any) -> bool: ...
    def get(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getId(self) -> str: ...
    def getLong(self, temporalField: java.time.temporal.TemporalField) -> int: ...
    def getRules(self) -> java.time.zone.ZoneRules: ...
    def getTotalSeconds(self) -> int: ...
    def hashCode(self) -> int: ...
    def isSupported(self, temporalField: java.time.temporal.TemporalField) -> bool: ...
    @typing.overload
    @staticmethod
    def of(string: str) -> ZoneId: ...
    @typing.overload
    @staticmethod
    def of(string: str, map: typing.Union[java.util.Map[str, str], typing.Mapping[str, str]]) -> ZoneId: ...
    @typing.overload
    @staticmethod
    def of(string: str) -> 'ZoneOffset': ...
    @staticmethod
    def ofHours(int: int) -> 'ZoneOffset': ...
    @staticmethod
    def ofHoursMinutes(int: int, int2: int) -> 'ZoneOffset': ...
    @staticmethod
    def ofHoursMinutesSeconds(int: int, int2: int, int3: int) -> 'ZoneOffset': ...
    @staticmethod
    def ofTotalSeconds(int: int) -> 'ZoneOffset': ...
    _query__R = typing.TypeVar('_query__R')  # <R>
    def query(self, temporalQuery: typing.Union[java.time.temporal.TemporalQuery[_query__R], typing.Callable[[java.time.temporal.TemporalAccessor], _query__R]]) -> _query__R: ...
    def range(self, temporalField: java.time.temporal.TemporalField) -> java.time.temporal.ValueRange: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.time")``.

    Clock: typing.Type[Clock]
    DateTimeException: typing.Type[DateTimeException]
    DayOfWeek: typing.Type[DayOfWeek]
    Duration: typing.Type[Duration]
    Instant: typing.Type[Instant]
    LocalDate: typing.Type[LocalDate]
    LocalDateTime: typing.Type[LocalDateTime]
    LocalTime: typing.Type[LocalTime]
    Month: typing.Type[Month]
    MonthDay: typing.Type[MonthDay]
    OffsetDateTime: typing.Type[OffsetDateTime]
    OffsetTime: typing.Type[OffsetTime]
    Period: typing.Type[Period]
    Year: typing.Type[Year]
    YearMonth: typing.Type[YearMonth]
    ZoneId: typing.Type[ZoneId]
    ZoneOffset: typing.Type[ZoneOffset]
    ZonedDateTime: typing.Type[ZonedDateTime]
    chrono: java.time.chrono.__module_protocol__
    format: java.time.format.__module_protocol__
    temporal: java.time.temporal.__module_protocol__
    zone: java.time.zone.__module_protocol__
